% Auto-generated chapter 17 for muslim
% Hadiths in this chapter: 84

\hadithdefcmd{muslim}{3568}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَمْرَةَ، أَنَّ عَائِشَةَ، أَخْبَرَتْهَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ عِنْدَهَا وَإِنَّهَا سَمِعَتْ صَوْتَ رَجُلٍ يَسْتَأْذِنُ فِي بَيْتِ حَفْصَةَ ‏.‏ قَالَتْ عَائِشَةُ فَقُلْتُ يَا رَسُولَ اللَّهِ هَذَا رَجُلٌ يَسْتَأْذِنُ فِي بَيْتِكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أُرَاهُ فُلاَنًا ‏"‏ ‏.‏ لِعَمِّ حَفْصَةَ مِنَ الرَّضَاعَةِ ‏.‏ فَقَالَتْ عَائِشَةُ يَا رَسُولَ اللَّهِ لَوْ كَانَ فُلاَنٌ حَيًّا - لِعَمِّهَا مِنَ الرَّضَاعَةِ - دَخَلَ عَلَىَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ إِنَّ الرَّضَاعَةَ تُحَرِّمُ مَا تُحَرِّمُ الْوِلاَدَةُ ‏"‏ ‏.‏\hadithno{3568}\hadithtrans{A'isha (Allah be pleased with her) reported tha Allah's Messenger (ﷺ) was with her and she heard the voice of a person seeking permission to enter the house of Hafsa. 'A'isha (Allah he pleased with her) said:Allah's Messenger, he is the person who seeks permission to enter your house, whereupon Allah's Messenger (ﷺ) said: I think he is so and so (uncle of Hafsa by reason of fosterage). 'A'isha said: Messenger of Allah, if so and so (her uncle by reason of fosterage) were alive, could he enter my house? Allah's Messenger (ﷺ) said: Yes. Fosterage makes unlawful what consanguinity makes unlawful}}
\hadithdefcmd{muslim}{3569}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنِي أَبُو مَعْمَرٍ، إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ الْهُذَلِيُّ حَدَّثَنَا عَلِيُّ بْنُ هَاشِمِ بْنِ الْبَرِيدِ، جَمِيعًا عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي، بَكْرٍ عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَحْرُمُ مِنَ الرَّضَاعَةِ مَا يَحْرُمُ مِنَ الْوِلاَدَةِ ‏"‏ ‏.‏\hadithno{3569}\hadithtrans{A'isha (Allah be pleased with her) reported Allah's Messenger (ﷺ) as saying:"What becomes unlawful through breastfeeding is that which becomes unlawful through birth}}
\hadithdefcmd{muslim}{3570}{وَحَدَّثَنِيهِ إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَ حَدِيثِ هِشَامِ بْنِ عُرْوَةَ ‏.‏\hadithno{3570}\hadithtrans{The above hadith is narrated through another chain}}
\hadithdefcmd{muslim}{3571}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّهَا أَخْبَرَتْهُ أَنَّ أَفْلَحَ - أَخَا أَبِي الْقُعَيْسِ - جَاءَ يَسْتَأْذِنُ عَلَيْهَا وَهُوَ عَمُّهَا مِنَ الرَّضَاعَةِ بَعْدَ أَنْ أُنْزِلَ الْحِجَابُ قَالَتْ فَأَبَيْتُ أَنْ آذَنَ لَهُ فَلَمَّا جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَخْبَرْتُهُ بِالَّذِي صَنَعْتُ فَأَمَرَنِي أَنْ آذَنَ لَهُ عَلَىَّ ‏.‏\hadithno{3571}\hadithtrans{A'isha (Allah be pleased with her) reported that Aflah, the brother of Abu'l-Qu'ais, who was her uncle by reason of fosterage, came, and asked her permission (to enter the house) after seclusion (Hijab) was instituted. I refused to admit him. When Allah's Messenger (ﷺ) came, I informed him what I had done. He commanded me to grant him permission (as the brother of her foster-father was also her uncle)}}
\hadithdefcmd{muslim}{3572}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ أَتَانِي عَمِّي مِنَ الرَّضَاعَةِ أَفْلَحُ بْنُ أَبِي قُعَيْسٍ ‏.‏ فَذَكَرَ بِمَعْنَى حَدِيثِ مَالِكٍ وَزَادَ قُلْتُ إِنَّمَا أَرْضَعَتْنِي الْمَرْأَةُ وَلَمْ يُرْضِعْنِي الرَّجُلُ قَالَ ‏ "‏ تَرِبَتْ يَدَاكِ أَوْ يَمِينُكِ‏"‏ ‏.‏\hadithno{3572}\hadithtrans{A'isha (Allah be pleased with her) reported:There came to me Aflah b. Abu Qulais, my uncle by reason of fosterage; the rest of the hadith is the same (but with this) addition:" I ('A'isha) said (to the Holy Prophet): It was the woman who suckled me and not the man, whereupon he (Allah's Messenger) said: May your hands or your right hand be besmeared with dust (you were mistaken)}}
\hadithdefcmd{muslim}{3573}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ أَنَّهُ، جَاءَ أَفْلَحُ أَخُو أَبِي الْقُعَيْسِ يَسْتَأْذِنُ عَلَيْهَا بَعْدَ مَا نَزَلَ الْحِجَابُ - وَكَانَ أَبُو الْقُعَيْسِ أَبَا عَائِشَةَ مِنَ الرَّضَاعَةِ - قَالَتْ عَائِشَةُ فَقُلْتُ وَاللَّهِ لاَ آذَنُ لأَفْلَحَ حَتَّى أَسْتَأْذِنَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَإِنَّ أَبَا الْقُعَيْسِ لَيْسَ هُوَ أَرْضَعَنِي وَلَكِنْ أَرْضَعَتْنِي امْرَأَتُهُ - قَالَتْ عَائِشَةُ - فَلَمَّا دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ أَفْلَحَ أَخَا أَبِي الْقُعَيْسِ جَاءَنِي يَسْتَأْذِنُ عَلَىَّ فَكَرِهْتُ أَنْ آذَنَ لَهُ حَتَّى أَسْتَأْذِنَكَ - قَالَتْ - فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ ائْذَنِي لَهُ ‏"‏ ‏.‏ قَالَ عُرْوَةُ فَبِذَلِكَ كَانَتْ عَائِشَةُ تَقُولُ حَرِّمُوا مِنَ الرَّضَاعَةِ مَا تُحَرِّمُونَ مِنَ النَّسَبِ ‏.‏\hadithno{3573}\hadithtrans{A'isha (Allah be pleased with her) reported that there came Aflah the brother, of Abu'l-Qu'ais, who sought her permission (to enter) after seclusion was instituted, and AbuQu'ais was the father of 'A'isha by reason of fosterage. 'A'isha said:By Allah, I would not permit Aflah unless I have solicited the opinion of Allah's Messenger (ﷺ) for Abu Qulais has not suckled me, but his wife has given me suck. 'A'isha' (Allah be pleased with her) said: When Allah's Messenger (ﷺ) entered, I said: Allah's Messenger, Aflah is the brother of Abu'l-Qulais; he came to me to seek my permission for entering (the houst). I did not like the idea of granting him permission until I had solicited your opinion. Thereupon Allah's Apostle (ﷺ) said: Grant him permission. 'Urwa said it was on account of this that 'A'isha used to say. What is unlawful by reason of consanguinity is unlawful by reason of fosterage}}
\hadithdefcmd{muslim}{3574}{وَحَدَّثَنَاهُ عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ جَاءَ أَفْلَحُ أَخُو أَبِي الْقُعَيْسِ يَسْتَأْذِنُ عَلَيْهَا ‏.‏ بِنَحْوِ حَدِيثِهِمْ وَفِيهِ ‏ "‏ فَإِنَّهُ عَمُّكِ تَرِبَتْ يَمِينُكِ ‏"‏ ‏.‏ وَكَانَ أَبُو الْقُعَيْسِ زَوْجَ الْمَرْأَةِ الَّتِي أَرْضَعَتْ عَائِشَةَ ‏.‏\hadithno{3574}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters (that 'A'isha said):There came Aflah, the brother of Abu'l Qulais (Allah be pleased with him), and sought permission from her, the rest of the hadith is the same (except for the words that the Holy Prophet) said:" He is your uncle. Let your hand be besmeared with dust. Abu'l Qulais was the husband of the woman who had suckled 'A'isha (Allah be pleased with her)}}
\hadithdefcmd{muslim}{3575}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا ابْنُ نُمَيْرٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ جَاءَ عَمِّي مِنَ الرَّضَاعَةِ يَسْتَأْذِنُ عَلَىَّ فَأَبَيْتُ أَنْ آذَنَ لَهُ حَتَّى أَسْتَأْمِرَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَلَمَّا جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم قُلْتُ إِنَّ عَمِّي مِنَ الرَّضَاعَةِ اسْتَأْذَنَ عَلَىَّ فَأَبَيْتُ أَنْ آذَنَ لَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَلْيَلِجْ عَلَيْكِ عَمُّكِ ‏"‏ ‏.‏ قُلْتُ إِنَّمَا أَرْضَعَتْنِي الْمَرْأَةُ وَلَمْ يُرْضِعْنِي الرَّجُلُ قَالَ ‏"‏ إِنَّهُ عَمُّكِ فَلْيَلِجْ عَلَيْكِ ‏"‏ ‏.‏\hadithno{3575}\hadithtrans{A'isha (Allah be pleased with her) reported:My foster uncle came to me and sought permission (to enter the house), but I refused him permission until I had solicited the opinion of Allah's Messenger (ﷺ). When Allah's Messenger (ﷺ) came, I said to him: My foster-uncle sought my permission to (enter the house), but I did not permit him, whereupon Allah's Messenger (ﷺ) said: You better admit your uncle (into the house). I ('A'isha) said: It was the woman who suckled me and not the man. (But he) said: He is your uncle, admit him}}
\hadithdefcmd{muslim}{3576}{وَحَدَّثَنِي أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - حَدَّثَنَا هِشَامٌ، بِهَذَا الإِسْنَادِ أَنَّ أَخَا أَبِي الْقُعَيْسِ، اسْتَأْذَنَ عَلَيْهَا ‏.‏ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{3576}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chain of transmitters (and the words are):" The brother of Abu'l-Qu'ais sought permission from her ('A'isha) (to enter the house). The rest is the same}}
\hadithdefcmd{muslim}{3577}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ غَيْرَ أَنَّهُ قَالَ اسْتَأْذَنَ عَلَيْهَا أَبُو الْقُعَيْسِ ‏.‏\hadithno{3577}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chain of transmitters but with a slight variation of words}}
\hadithdefcmd{muslim}{3578}{وَحَدَّثَنِي الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَمُحَمَّدُ بْنُ رَافِعٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ قَالَتِ، اسْتَأْذَنَ عَلَىَّ عَمِّي مِنَ الرَّضَاعَةِ أَبُو الْجَعْدِ فَرَدَدْتُهُ - قَالَ لِي هِشَامٌ إِنَّمَا هُوَ أَبُو الْقُعَيْسِ - فَلَمَّا جَاءَ النَّبِيُّ صلى الله عليه وسلم أَخْبَرْتُهُ بِذَلِكَ قَالَ ‏ "‏ فَهَلاَّ أَذِنْتِ لَهُ تَرِبَتْ يَمِينُكِ أَوْ يَدُكِ‏"‏ ‏.‏\hadithno{3578}\hadithtrans{A'isha (Allah be pleased with her) reported:My foster-uncle Abu'l Ja'd (kunya of Aflah) sought permission from me, which I refused. (Hisham said to me that Abu'l-Ja'd was in fact Abu'l-Qu'ais). When Allah's Apostle (ﷺ) came, I ('A'isha) informed him about it. He said: Why did you not permit him? Let your right hand or hand be besmeared with dust}}
\hadithdefcmd{muslim}{3579}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عِرَاكٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا أَخْبَرَتْهُ أَنَّ عَمَّهَا مِنَ الرَّضَاعَةِ - يُسَمَّى أَفْلَحَ - اسْتَأْذَنَ عَلَيْهَا فَحَجَبَتْهُ فَأَخْبَرَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهَا ‏ "‏ لاَ تَحْتَجِبِي مِنْهُ فَإِنَّهُ يَحْرُمُ مِنَ الرَّضَاعَةِ مَا يَحْرُمُ مِنَ النَّسَبِ ‏"‏ ‏.‏\hadithno{3579}\hadithtrans{A'isha (Allah be pleased with her) reported that her foster-uncle whose name was Aflah sought permission from her (to enter the house) but she observed seclusion from him, and informed Allah's Messenger (ﷺ) who said to her:Don't observe veil from him for he is Mahram (one with whom marriage cannot be contracted) on account of fosterage as one is Mahram on account of consanguinity}}
\hadithdefcmd{muslim}{3580}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ عِرَاكِ، بْنِ مَالِكٍ عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتِ اسْتَأْذَنَ عَلَىَّ أَفْلَحُ بْنُ قُعَيْسٍ فَأَبَيْتُ أَنْ آذَنَ، لَهُ فَأَرْسَلَ إِنِّي عَمُّكِ أَرْضَعَتْكِ امْرَأَةُ أَخِي ‏.‏ فَأَبَيْتُ أَنْ آذَنَ لَهُ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ ‏ "‏ لِيَدْخُلْ عَلَيْكِ فَإِنَّهُ عَمُّكِ ‏"‏ ‏.‏\hadithno{3580}\hadithtrans{A'isha (Allah be pleased with her) reported:Aflah b. Qu'ais sought permission from me (to enter the house), but I refused to grant him the permission, and he sent me (the message saying): I am your uncle (in the sense) that the wife of my brother has suckled you, (but still) I refused to grant him permission. There came the Messenger of Allah (ﷺ) and I made a mention of it to him, and he said: He can enter (your house), for he is your uncle}}
\hadithdefcmd{muslim}{3581}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْعَلاَءِ، - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالُوا حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عَلِيٍّ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ مَا لَكَ تَنَوَّقُ فِي قُرَيْشٍ وَتَدَعُنَا فَقَالَ ‏"‏ وَعِنْدَكُمْ شَىْءٌ ‏"‏ ‏.‏ قُلْتُ نَعَمْ بِنْتُ حَمْزَةَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهَا لاَ تَحِلُّ لِي إِنَّهَا ابْنَةُ أَخِي مِنَ الرَّضَاعَةِ ‏"‏ ‏.‏\hadithno{3581}\hadithtrans{Ali (Allah be pleased with him) reported having said this:Messenger of Allah, why is it that you select (your wife) from among the Quraish, but you ignore us (the nearest of the kin)? Thereupon he said: Have you anything for me (a suitable match for me)? I said; Yes, the daughter of Hamza, whereupon Allah's Messenger (ﷺ) said: She is not lawful for me, for she is the daughter of my brother by reason of fosterage}}
\hadithdefcmd{muslim}{3582}{وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، عَنْ جَرِيرٍ، ح وَحَدَّثَنَا ابْنُ، نُمَيْرٍ حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، كُلُّهُمْ عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{3582}\hadithtrans{A hadith like this has been narrated on the authority of A'mash with the same chain of transmitters}}
\hadithdefcmd{muslim}{3583}{وَحَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ، عَبَّاسٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم أُرِيدَ عَلَى ابْنَةِ حَمْزَةَ فَقَالَ ‏ "‏ إِنَّهَا لاَ تَحِلُّ لِي إِنَّهَا ابْنَةُ أَخِي مِنَ الرَّضَاعَةِ وَيَحْرُمُ مِنَ الرَّضَاعَةِ مَا يَحْرُمُ مِنَ الرَّحِمِ ‏"‏ ‏.‏\hadithno{3583}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported:It was proposed that he (the Holy Prophet) be married to the daughter of Hamza, whereupon he said: She is not lawful for me for she is the daughter of my foster-brother, and that is unlawful by reason of fosterage what is unlawful by reason of genealogy}}
\hadithdefcmd{muslim}{3584}{وَحَدَّثَنَاهُ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى، وَهُوَ الْقَطَّانُ ح وَحَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، بْنِ مِهْرَانَ الْقُطَعِيُّ حَدَّثَنَا بِشْرُ بْنُ عُمَرَ، جَمِيعًا عَنْ شُعْبَةَ، ح وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، كِلاَهُمَا عَنْ قَتَادَةَ، بِإِسْنَادِ هَمَّامٍ سَوَاءً غَيْرَ أَنَّ حَدِيثَ شُعْبَةَ انْتَهَى عِنْدَ قَوْلِهِ ‏"‏ ابْنَةُ أَخِي مِنَ الرَّضَاعَةِ ‏"‏ ‏.‏ وَفِي حَدِيثِ سَعِيدٍ ‏"‏ وَإِنَّهُ يَحْرُمُ مِنَ الرَّضَاعَةِ مَا يَحْرُمُ مِنَ النَّسَبِ ‏"‏ ‏.‏ وَفِي رِوَايَةِ بِشْرِ بْنِ عُمَرَ سَمِعْتُ جَابِرَ بْنَ زَيْدٍ ‏.‏\hadithno{3584}\hadithtrans{A hadith like this is narrated on the authority of Hammam, Sa'id, Bishr b 'Umar, but with a small variation of words}}
\hadithdefcmd{muslim}{3585}{وَحَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَأَحْمَدُ بْنُ عِيسَى، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَخْرَمَةُ بْنُ بُكَيْرٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ مُسْلِمٍ، يَقُولُ سَمِعْتُ مُحَمَّدَ بْنَ مُسْلِمٍ، يَقُولُ سَمِعْتُ حُمَيْدَ بْنَ عَبْدِ الرَّحْمَنِ، يَقُولُ سَمِعْتُ أُمَّ سَلَمَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم تَقُولُ قِيلَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَيْنَ أَنْتَ يَا رَسُولَ اللَّهِ عَنِ ابْنَةِ حَمْزَةَ ‏.‏ أَوْ قِيلَ أَلاَ تَخْطُبُ بِنْتَ حَمْزَةَ بْنِ عَبْدِ الْمُطَّلِبِ قَالَ ‏ "‏ إِنَّ حَمْزَةَ أَخِي مِنَ الرَّضَاعَةِ ‏"‏ ‏.‏\hadithno{3585}\hadithtrans{Umm Salama (Allah be pleased with her), the wife of Allah's Apostle (ﷺ), said:It was said to the Messenger of Allah (ﷺ): Is not the daughter of Hamza a suitable match for you? Or it was said: Why don't you propose to marry the daughter of Hamza, the son of Abd al-Muttalib? Thereupon he said: Hamza is my brother by reason of fosterage}}
\hadithdefcmd{muslim}{3586}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو أُسَامَةَ، أَخْبَرَنَا هِشَامٌ، أَخْبَرَنَا أَبِي، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، عَنْ أُمِّ حَبِيبَةَ بِنْتِ أَبِي سُفْيَانَ، قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُلْتُ لَهُ هَلْ لَكَ فِي أُخْتِي بِنْتِ أَبِي سُفْيَانَ فَقَالَ ‏"‏ أَفْعَلُ مَاذَا ‏"‏ ‏.‏ قُلْتُ تَنْكِحُهَا ‏.‏ قَالَ ‏"‏ أَوَتُحِبِّينَ ذَلِكَ ‏"‏ ‏.‏ قُلْتُ لَسْتُ لَكَ بِمُخْلِيَةٍ وَأَحَبُّ مَنْ شَرِكَنِي فِي الْخَيْرِ أُخْتِي ‏.‏ قَالَ ‏"‏ فَإِنَّهَا لاَ تَحِلُّ لِي ‏"‏ ‏.‏ قُلْتُ فَإِنِّي أُخْبِرْتُ أَنَّكَ تَخْطُبُ دُرَّةَ بِنْتَ أَبِي سَلَمَةَ ‏.‏ قَالَ ‏"‏ بِنْتَ أُمِّ سَلَمَةَ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ لَوْ أَنَّهَا لَمْ تَكُنْ رَبِيبَتِي فِي حَجْرِي مَا حَلَّتْ لِي إِنَّهَا ابْنَةُ أَخِي مِنَ الرَّضَاعَةِ أَرْضَعَتْنِي وَأَبَاهَا ثُوَيْبَةُ فَلاَ تَعْرِضْنَ عَلَىَّ بَنَاتِكُنَّ وَلاَ أَخَوَاتِكُنَّ ‏"‏ ‏.‏\hadithno{3586}\hadithtrans{Umm Habiba, the daughter of AbuSufyan, reported:The Messenger of Allah (ﷺ) came to me and I said to him: Have you any inclination towards my the daughter of Abu Sufyan? He (the Holy Prophet) said: Then what should I do? I said: Marry her. He said: Do you like that? I said: I am not the exclusive (wife) of yours; I, therefore, wish to join my sister in good. He, said: She is not lawful for me. I said: I have been informed that you have given the proposal of marriage to Durrah daughter of Abu Salama He raid: You mean the daughter of Umm Salama? I said: Yes. He said: Even if she had not been my step-daughter brought up under my guardianship, she would not have been lawful for me, for she is the daughter of my foster-brother (Hamza), for Thuwaiba had suckled me and her father. So do not give me the proposal of the marriage of your daughters and sisters}}
\hadithdefcmd{muslim}{3587}{وَحَدَّثَنِيهِ سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّاءَ بْنِ أَبِي زَائِدَةَ، ح وَحَدَّثَنَا عَمْرٌو، النَّاقِدُ حَدَّثَنَا الأَسْوَدُ بْنُ عَامِرٍ، أَخْبَرَنَا زُهَيْرٌ، كِلاَهُمَا عَنْ هِشَامِ بْنِ عُرْوَةَ، بِهَذَا الإِسْنَادِ سَوَاءً ‏.‏\hadithno{3587}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chain of transmitters}}
\hadithdefcmd{muslim}{3588}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، أَنَّحَدَّثَهُ أَنَّ زَيْنَبَ بِنْتَ أَبِي سَلَمَةَ حَدَّثَتْهُ أَنَّ أُمَّ حَبِيبَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم حَدَّثَتْهَا أَنَّهَا قَالَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ انْكِحْ أُخْتِي عَزَّةَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتُحِبِّينَ ذَلِكِ ‏"‏ ‏.‏ فَقَالَتْ نَعَمْ يَا رَسُولَ اللَّهِ لَسْتُ لَكَ بِمُخْلِيَةٍ وَأَحَبُّ مَنْ شَرِكَنِي فِي خَيْرٍ أُخْتِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَإِنَّ ذَلِكِ لاَ يَحِلُّ لِي ‏"‏ ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ فَإِنَّا نَتَحَدَّثُ أَنَّكَ تُرِيدُ أَنْ تَنْكِحَ دُرَّةَ بِنْتَ أَبِي سَلَمَةَ ‏.‏ قَالَ ‏"‏ بِنْتَ أَبِي سَلَمَةَ ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ أَنَّهَا لَمْ تَكُنْ رَبِيبَتِي فِي حَجْرِي مَا حَلَّتْ لِي إِنَّهَا ابْنَةُ أَخِي مِنَ الرَّضَاعَةِ أَرْضَعَتْنِي وَأَبَا سَلَمَةَ ثُوَيْبَةُ فَلاَ تَعْرِضْنَ عَلَىَّ بَنَاتِكُنَّ وَلاَ أَخَوَاتِكُنَّ ‏"‏ ‏.‏\hadithno{3588}\hadithtrans{Umm Habiba, the wife of Allah's Apostle (ﷺ), reported that she said to Allah's Messenger (ﷺ):Messenger of Allah, marry my sister 'Azza, whereupon Allah's Messenger (ﷺ) said: Do you like it? She said: Yes, Messenger of Allah, I am not the exclusive wife of yours, and I wish that the person who joins me in good should be my sister. Thereupon Allah's Messenger (ﷺ) said: That is not lawful for me. I said: Messenger of Allah, we discussed that You intend to marry Durrah bint Abu Salama. He (the Holy Prophet) said: You mean the daughter of Abu Salama? She said: Yes, whereupon Allah's Messenger (may. peace be upon him) said: Even if she were not the step-daughter of mine, brought up under my guardianship, she would not have been lawful for me, for she is the daughter of my foster-brother. Thuwaiba gave me suck and to Abu Salama (also), so do not offer to me your daughters and sisters}}
\hadithdefcmd{muslim}{3589}{وَحَدَّثَنِيهِ عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ، خَالِدٍ ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ الزُّهْرِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ، اللَّهِ بْنِ مُسْلِمٍ كِلاَهُمَا عَنِ الزُّهْرِيِّ، بِإِسْنَادِ ابْنِ أَبِي حَبِيبٍ عَنْهُ نَحْوَ حَدِيثِهِ وَلَمْ يُسَمِّ أَحَدٌ مِنْهُمْ فِي حَدِيثِهِ عَزَّةَ غَيْرُ يَزِيدَ بْنِ أَبِي حَبِيبٍ ‏.‏\hadithno{3589}\hadithtrans{The above hadith is narratted through other chains except they did not mention 'Azza like the chain of Yazid Bin Abi Habib}}
\hadithdefcmd{muslim}{3590}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ، اللَّهِ بْنِ نُمَيْرٍ حَدَّثَنَا إِسْمَاعِيلُ، ح وَحَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، كِلاَهُمَا عَنْ أَيُّوبَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ سُوَيْدٌ وَزُهَيْرٌ إِنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُحَرِّمُ الْمَصَّةُ وَالْمَصَّتَانِ ‏"‏ ‏.‏\hadithno{3590}\hadithtrans{A'isha (Allah be pleased with her), Suwaid and Zubair reported Allah's Apostle (ﷺ) as saying:One suckling or two do not make (marriage) unlawful}}
\hadithdefcmd{muslim}{3591}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَعَمْرٌو النَّاقِدُ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، كُلُّهُمْ عَنِ الْمُعْتَمِرِ، - وَاللَّفْظُ لِيَحْيَى - أَخْبَرَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ أَيُّوبَ، يُحَدِّثُ عَنْ أَبِي الْخَلِيلِ، عَنْ عَبْدِ، اللَّهِ بْنِ الْحَارِثِ عَنْ أُمِّ الْفَضْلِ، قَالَتْ دَخَلَ أَعْرَابِيٌّ عَلَى نَبِيِّ اللَّهِ صلى الله عليه وسلم وَهُوَ فِي بَيْتِي فَقَالَ يَا نَبِيَّ اللَّهِ إِنِّي كَانَتْ لِي امْرَأَةٌ فَتَزَوَّجْتُ عَلَيْهَا أُخْرَى فَزَعَمَتِ امْرَأَتِي الأُولَى أَنَّهَا أَرْضَعَتِ امْرَأَتِي الْحُدْثَى رَضْعَةً أَوْ رَضْعَتَيْنِ ‏.‏ فَقَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُحَرِّمُ الإِمْلاَجَةُ وَالإِمْلاَجَتَانِ ‏"‏ ‏.‏ قَالَ عَمْرٌو فِي رِوَايَتِهِ عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ نَوْفَلٍ ‏.‏\hadithno{3591}\hadithtrans{Umm al-Fadl reported:A bedouin came to Allah's Apostle (ﷺ) when he was in my house and said: Allah's Apostle, I have had a wife and I married another besides her, and my first wife claimed that she had suckled once or twice my newly married wife, thereupon Allah's Apostle (ﷺ) said: One suckling or two do not make the (marriage) unlawful}}
\hadithdefcmd{muslim}{3592}{وَحَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، حَدَّثَنَا مُعَاذٌ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ صَالِحِ بْنِ أَبِي مَرْيَمَ أَبِي الْخَلِيلِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ أُمِّ الْفَضْلِ، أَنَّ رَجُلاً، مِنْ بَنِي عَامِرِ بْنِ صَعْصَعَةَ قَالَ يَا نَبِيَّ اللَّهِ هَلْ تُحَرِّمُ الرَّضْعَةُ الْوَاحِدَةُ قَالَ ‏ "‏ لاَ ‏"‏ ‏.‏\hadithno{3592}\hadithtrans{Umm Fadl (Allah be pleased with her) reported that a person from Banu 'Amir b. Sa'sa said:Allah's Apostle, does one suckling make the (marriage) unlawful? He said: No}}
\hadithdefcmd{muslim}{3593}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَبِي الْخَلِيلِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، أَنَّ أُمَّ الْفَضْلِ، حَدَّثَتْ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُحَرِّمُ الرَّضْعَةُ أَوِ الرَّضْعَتَانِ أَوِ الْمَصَّةُ أَوِ الْمَصَّتَانِ ‏"‏ ‏.‏\hadithno{3593}\hadithtrans{Umm Fadl (Allah be pleased with her) reported that Allah's Apostle (ﷺ) said:Being suckled once or twice, or one suckling or two, do not make marriage unlawful}}
\hadithdefcmd{muslim}{3594}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، جَمِيعًا عَنْ عَبْدَةَ بْنِ سُلَيْمَانَ، عَنِ ابْنِ أَبِي عَرُوبَةَ، بِهَذَا الإِسْنَادِ أَمَّا إِسْحَاقُ فَقَالَ كَرِوَايَةِ ابْنِ بِشْرٍ ‏"‏ أَوِ الرَّضْعَتَانِ أَوِ الْمَصَّتَانِ ‏"‏ ‏.‏ وَأَمَّا ابْنُ أَبِي شَيْبَةَ فَقَالَ ‏"‏ وَالرَّضْعَتَانِ وَالْمَصَّتَانِ ‏"‏ ‏.‏\hadithno{3594}\hadithtrans{In the narration transmitted on the authority of Ibn Bishr there is a mention of two sucklings and Ibn Abu Shaiba has narrated it with a small variation of wording}}
\hadithdefcmd{muslim}{3595}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ قَتَادَةَ، عَنْ أَبِي الْخَلِيلِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ نَوْفَلٍ، عَنْ أَمِّ الْفَضْلِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُحَرِّمُ الإِمْلاَجَةُ وَالإِمْلاَجَتَانِ ‏"‏ ‏\hadithno{3595}\hadithtrans{Umm Fadl (Allah be pleased with her) reported Allah's Apostle (may peace be'apon him) having said this:One or two sucklings do not make (the marriage) unlawful}}
\hadithdefcmd{muslim}{3596}{حَدَّثَنِي أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، حَدَّثَنَا حَبَّانُ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَبِي، الْخَلِيلِ عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ أُمِّ الْفَضْلِ، سَأَلَ رَجُلٌ النَّبِيَّ صلى الله عليه وسلم أَتُحَرِّمُ الْمَصَّةُ فَقَالَ ‏ "‏ لاَ ‏"‏ ‏.‏\hadithno{3596}\hadithtrans{Umm Fadl (Allah be pleased with her) reported that a person asked Allah's Apostle (ﷺ):Does one suckling make (the marriage) unlawful? He said: No}}
\hadithdefcmd{muslim}{3597}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ كَانَ فِيمَا أُنْزِلَ مِنَ الْقُرْآنِ عَشْرُ رَضَعَاتٍ مَعْلُومَاتٍ يُحَرِّمْنَ ‏.‏ ثُمَّ نُسِخْنَ بِخَمْسٍ مَعْلُومَاتٍ فَتُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُنَّ فِيمَا يُقْرَأُ مِنَ الْقُرْآنِ ‏.‏\hadithno{3597}\hadithtrans{A'isha (Allah be pleased with, her) reported that it had been revealed in the Holy Qur'an that ten clear sucklings make the marriage unlawful, then it was abrogated (and substituted) by five sucklings and Allah's Apostle (ﷺ) died and it was before that time (found) in the Holy Qur'an (and recited by the Muslims)}}
\hadithdefcmd{muslim}{3598}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ يَحْيَى، - وَهُوَ ابْنُ سَعِيدٍ - عَنْ عَمْرَةَ، أَنَّهَا سَمِعَتْ عَائِشَةَ، تَقُولُ - وَهْىَ تَذْكُرُ الَّذِي يُحَرِّمُ مِنَ الرَّضَاعَةِ - قَالَتْ عَمْرَةُ فَقَالَتْ عَائِشَةُ نَزَلَ فِي الْقُرْآنِ عَشْرُ رَضَعَاتٍ مَعْلُومَاتٍ ثُمَّ نَزَلَ أَيْضًا خَمْسٌ مَعْلُومَاتٌ ‏.‏\hadithno{3598}\hadithtrans{Amra reported that she heard 'A'isha (Allah he pleased with her) discussing fosterage which (makes marriage) unlawful; and she ('A'isha) said:There was revealed in the Holy Qur'an ten clear sucklings, and then five clear (sucklings)}}
\hadithdefcmd{muslim}{3599}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، قَالَ أَخْبَرَتْنِي عَمْرَةُ، أَنَّهَا سَمِعَتْ عَائِشَةَ، تَقُولُ ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{3599}\hadithtrans{Ahadith like this is transmitted by 'A'isha through another chain of narrators}}
\hadithdefcmd{muslim}{3600}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الرَّحْمَنِ، بْنِ الْقَاسِمِ عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتْ سَهْلَةُ بِنْتُ سُهَيْلٍ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي أَرَى فِي وَجْهِ أَبِي حُذَيْفَةَ مِنْ دُخُولِ سَالِمٍ - وَهُوَ حَلِيفُهُ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَرْضِعِيهِ ‏"‏ ‏.‏ قَالَتْ وَكَيْفَ أُرْضِعُهُ وَهُوَ رَجُلٌ كَبِيرٌ فَتَبَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ قَدْ عَلِمْتُ أَنَّهُ رَجُلٌ كَبِيرٌ ‏"‏ ‏.‏ زَادَ عَمْرٌو فِي حَدِيثِهِ وَكَانَ قَدْ شَهِدَ بَدْرًا ‏.‏ وَفِي رِوَايَةِ ابْنِ أَبِي عُمَرَ فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3600}\hadithtrans{A'isha (Allah be pleased with her) reported that Sahla bint Suhail came to Allah's Apostle (may peace be eupon him) and said:Messengerof Allah, I see on the face of Abu Hudhaifa (signs of disgust) on entering of Salim (who is an ally) into (our house), whereupon Allah's Apostle (ﷺ) said: Suckle him. She said: How can I suckle him as he is a grown-up man? Allah's Messenger (ﷺ) smiled and said: I already know that he is a young man 'Amr has made this addition in his narration that he participated in the Battle of Badr and in the narration of Ibn 'Umar (the words are): Allah's Messenger (ﷺ) laughed}}
\hadithdefcmd{muslim}{3601}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، وَمُحَمَّدُ بْنُ أَبِي عُمَرَ، جَمِيعًا عَنِ الثَّقَفِيِّ، - قَالَ ابْنُ أَبِي عُمَرَ حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، - عَنْ أَيُّوبَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، أَنَّ سَالِمًا، مَوْلَى أَبِي حُذَيْفَةَ كَانَ مَعَ أَبِي حُذَيْفَةَ وَأَهْلِهِ فِي بَيْتِهِمْ فَأَتَتْ - تَعْنِي ابْنَةَ سُهَيْلٍ - النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ إِنَّ سَالِمًا قَدْ بَلَغَ مَا يَبْلُغُ الرِّجَالُ وَعَقَلَ مَا عَقَلُوا وَإِنَّهُ يَدْخُلُ عَلَيْنَا وَإِنِّي أَظُنُّ أَنَّ فِي نَفْسِ أَبِي حُذَيْفَةَ مِنْ ذَلِكَ شَيْئًا ‏.‏ فَقَالَ لَهَا النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَرْضِعِيهِ تَحْرُمِي عَلَيْهِ وَيَذْهَبِ الَّذِي فِي نَفْسِ أَبِي حُذَيْفَةَ ‏"‏ ‏.‏ فَرَجَعَتْ فَقَالَتْ إِنِّي قَدْ أَرْضَعْتُهُ فَذَهَبَ الَّذِي فِي نَفْسِ أَبِي حُذَيْفَةَ ‏.‏\hadithno{3601}\hadithtrans{A'isha (Allah be pleased with her) reported that Salim, the freed slave of Abu Hadhaifa, lived with him and his family in their house. She (i. e. the daughter of Suhail came to Allah's Apostle (ﷺ) and said:Salim has attained (purbety) as men attain, and he understands what they understand, and he enters our house freely, I, however, perceive that something (rankles) in the heart of Abu Hudhaifa, whereupon Allah's Apostle (ﷺ) said to her: Suckle him and you would become unlawful for him, and (the rankling) which Abu Hudhaifa feels in his heart will disappear. She returned and said: So I suckled him, and what (was there) in the heart of Abu Hudhaifa disappeared}}
\hadithdefcmd{muslim}{3602}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ رَافِعٍ، - وَاللَّفْظُ لاِبْنِ رَافِعٍ - قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنَا ابْنُ أَبِي مُلَيْكَةَ، أَنَّ الْقَاسِمَ بْنَ مُحَمَّدِ بْنِ أَبِي بَكْرٍ، أَخْبَرَهُ أَنَّ عَائِشَةَ أَخْبَرَتْهُ أَنَّ سَهْلَةَ بِنْتَ سُهَيْلِ بْنِ عَمْرٍو جَاءَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ سَالِمًا - لِسَالِمٍ مَوْلَى أَبِي حُذَيْفَةَ - مَعَنَا فِي بَيْتِنَا وَقَدْ بَلَغَ مَا يَبْلُغُ الرِّجَالُ وَعَلِمَ مَا يَعْلَمُ الرِّجَالُ ‏.‏ قَالَ ‏ "‏ أَرْضِعِيهِ تَحْرُمِي عَلَيْهِ ‏"‏ ‏.‏ قَالَ فَمَكَثْتُ سَنَةً أَوْ قَرِيبًا مِنْهَا لاَ أُحَدِّثُ بِهِ وَهِبْتُهُ ثُمَّ لَقِيتُ الْقَاسِمَ فَقُلْتُ لَهُ لَقَدْ حَدَّثْتَنِي حَدِيثًا مَا حَدَّثْتُهُ بَعْدُ ‏.‏ قَالَ فَمَا هُوَ فَأَخْبَرْتُهُ ‏.‏ قَالَ فَحَدِّثْهُ عَنِّي أَنَّ عَائِشَةَ أَخْبَرَتْنِيهِ ‏.‏\hadithno{3602}\hadithtrans{Ibn Abu Mulaika reported that al-Qasim b. Muhammad b. Abu Bakr had narrated to him that 'A'isha (Allah be pleased with her) reported that Sahla bint Suhail b. 'Amr came to Allah's Apostle (ﷺ) and said:Messenger of Allah, Salim (the freed slave of Abu Hudhaifa) is living with us in our house, and he has attained (puberty) as men attain it and has acquired knowledge (of the sex problems) as men acquire, whereupon he said: Suckle him so that he may become unlawful (in regard to marriage) for you He (Ibn Abu Mulaika) said: I refrained from (narrating this hadith) for a year or so on account of fear. I then met al-Qasim and said to him: You narrated to me a hadith which I did not narrate (to anyone) afterwards. He said: What is that? I informed him, whereupon he said: Narrate it on my authority that 'A'isha (Allah be pleased with her) had narrated that to me}}
\hadithdefcmd{muslim}{3603}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ حُمَيْدِ بْنِ نَافِعٍ، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، قَالَتْ قَالَتْ أُمُّ سَلَمَةَ لِعَائِشَةَ إِنَّهُ يَدْخُلُ عَلَيْكِ الْغُلاَمُ الأَيْفَعُ الَّذِي مَا أُحِبُّ أَنْ يَدْخُلَ عَلَىَّ ‏.‏ قَالَ فَقَالَتْ عَائِشَةُ أَمَا لَكِ فِي رَسُولِ اللَّهِ صلى الله عليه وسلم أُسْوَةٌ قَالَتْ إِنَّ امْرَأَةَ أَبِي حُذَيْفَةَ قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ سَالِمًا يَدْخُلُ عَلَىَّ وَهُوَ رَجُلٌ وَفِي نَفْسِ أَبِي حُذَيْفَةَ مِنْهُ شَىْءٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَرْضِعِيهِ حَتَّى يَدْخُلَ عَلَيْكِ ‏"‏ ‏.‏\hadithno{3603}\hadithtrans{Umm Salama said to 'A'isha (Allah be pleased with her):A young boy who is at the threshold of puberty comes to you. I, however, do not like that he should come to me, whereupon 'A'isha (Allah be pleased with her) said: Don't you see in Allah's Messenger (ﷺ) a model for you? She also said: The wife of Abu Hudhaifa said: Messenger of Allah, Salim comes to me and now he is a (grown-up) person, and there is something that (rankles) in the mind of Abu Hudhaifa about him, whereupon Allah's Messenger (ﷺ) said: Suckle him (so that he may become your foster-child), and thus he may be able to come to you (freely)}}
\hadithdefcmd{muslim}{3604}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَهَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، - وَاللَّفْظُ لِهَارُونَ - قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَخْرَمَةُ بْنُ بُكَيْرٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ حُمَيْدَ بْنَ نَافِعٍ، يَقُولُ سَمِعْتُ زَيْنَبَ، بِنْتَ أَبِي سَلَمَةَ تَقُولُ سَمِعْتُ أُمَّ سَلَمَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم تَقُولُ لِعَائِشَةَ وَاللَّهِ مَا تَطِيبُ نَفْسِي أَنْ يَرَانِي الْغُلاَمُ قَدِ اسْتَغْنَى عَنِ الرَّضَاعَةِ ‏.‏ فَقَالَتْ لِمَ قَدْ جَاءَتْ سَهْلَةُ بِنْتُ سُهَيْلٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ وَاللَّهِ إِنِّي لأَرَى فِي وَجْهِ أَبِي حُذَيْفَةَ مِنْ دُخُولِ سَالِمٍ ‏.‏ قَالَتْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرْضِعِيهِ ‏"‏ ‏.‏ فَقَالَتْ إِنَّهُ ذُو لِحْيَةٍ ‏.‏ فَقَالَ ‏"‏ أَرْضِعِيهِ يَذْهَبْ مَا فِي وَجْهِ أَبِي حُذَيْفَةَ ‏"‏ ‏.‏ فَقَالَتْ وَاللَّهِ مَا عَرَفْتُهُ فِي وَجْهِ أَبِي حُذَيْفَةَ ‏.‏\hadithno{3604}\hadithtrans{Zainab daughter of Abu Salama reported:I heard Umm Salama, the wife of Allah's Apostle (may peace be upon himy, saying to 'A'isha: By Allah, I do not like to be seen by a young boy who has passed the period of fosterage, whereupon she ('A'isha) said: Why is it so? Sahla daughter of Suhail came to Allah's Messenger (ﷺ) and said: Allah's Messenger, I swear by Allah that I see in the face of Abu Hudhaifa (the signs of disgust) on account of entering of Salim (in the house), whereupon Allah's Messenger (ﷺ) said: Suckle him. She (Sahla bint Suhail) said: He has a heard. But he (again) said: Suckle him, and it would remove what is there (expression of disgust) on the face of Abu Hudhaifa. She said: (I did that) and, by Allah, I did not see (any sign of disgust) on the face of Abu Hudhaifa}}
\hadithdefcmd{muslim}{3605}{حَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ، خَالِدٍ عَنِ ابْنِ شِهَابٍ، أَنَّهُ قَالَ أَخْبَرَنِي أَبُو عُبَيْدَةَ بْنُ عَبْدِ اللَّهِ بْنِ زَمْعَةَ، أَنَّ أُمَّهُ، زَيْنَبَ بِنْتَ أَبِي سَلَمَةَ أَخْبَرَتْهُ أَنَّ أُمَّهَا أُمَّ سَلَمَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم كَانَتْ تَقُولُ أَبَى سَائِرُ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم أَنْ يُدْخِلْنَ عَلَيْهِنَّ أَحَدًا بِتِلْكَ الرَّضَاعَةِ وَقُلْنَ لِعَائِشَةَ وَاللَّهِ مَا نَرَى هَذَا إِلاَّ رُخْصَةً أَرْخَصَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم لِسَالِمٍ خَاصَّةً فَمَا هُوَ بِدَاخِلٍ عَلَيْنَا أَحَدٌ بِهَذِهِ الرَّضَاعَةِ وَلاَ رَائِينَا\hadithno{3605}\hadithtrans{Umm Salama, the wife of Allah's Apostle (ﷺ), used to say that all wives of Allah's Apostle (ﷺ) disclaimed the idea that one with this type of fosterage (having been suckled after the proper period) should come to them. and said to 'A'isha:By Allah, we do not find this but a sort of concession given by Allah's Messenger (ﷺ) only for Salim, and no one was ging to be allowed to enter (our houses) with this type of fosterage and we do not subscribe to this view}}
\hadithdefcmd{muslim}{3606}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، قَالَ قَالَتْ عَائِشَةُ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعِنْدِي رَجُلٌ قَاعِدٌ فَاشْتَدَّ ذَلِكَ عَلَيْهِ وَرَأَيْتُ الْغَضَبَ فِي وَجْهِهِ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّهُ أَخِي مِنَ الرَّضَاعَةِ ‏.‏ قَالَتْ فَقَالَ ‏ "‏ انْظُرْنَ إِخْوَتَكُنَّ مِنَ الرَّضَاعَةِ فَإِنَّمَا الرَّضَاعَةُ مِنَ الْمَجَاعَةِ‏\hadithno{3606}\hadithtrans{A'isha (Allah be pleased with her) reported:Allah's Messenger (ﷺ) visited me when a man was sitting near me, and he seemed to disapprove of that. And I saw signs of anger on his face and I said: Messenger of Allah, he is my brother by forsterage, whereupon he said: Consider who your brothers are because of fosterage since fosterage is through hunger (i. e. in infancy)}}
\hadithdefcmd{muslim}{3607}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي قَالاَ، جَمِيعًا حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، جَمِيعًا عَنْ سُفْيَانَ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا حُسَيْنٌ الْجُعْفِيُّ، عَنْ زَائِدَةَ، كُلُّهُمْ عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، بِإِسْنَادِ أَبِي الأَحْوَصِ كَمَعْنَى حَدِيثِهِ غَيْرَ أَنَّهُمْ قَالُوا ‏ "‏ مِنَ الْمَجَاعَةِ ‏\hadithno{3607}\hadithtrans{This hadith is narrated on the authority of Abu al-Ahwas with another chain of transmitters and a slight variation of words}}
\hadithdefcmd{muslim}{3608}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ الْقَوَارِيرِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدُ، بْنُ أَبِي عَرُوبَةَ عَنْ قَتَادَةَ، عَنْ صَالِحٍ أَبِي الْخَلِيلِ، عَنْ أَبِي عَلْقَمَةَ الْهَاشِمِيِّ، عَنْ أَبِي سَعِيدٍ، الْخُدْرِيِّ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَوْمَ حُنَيْنٍ بَعَثَ جَيْشًا إِلَى أَوْطَاسٍ فَلَقُوا عَدُوًّا فَقَاتَلُوهُمْ فَظَهَرُوا عَلَيْهِمْ وَأَصَابُوا لَهُمْ سَبَايَا فَكَأَنَّ نَاسًا مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم تَحَرَّجُوا مِنْ غِشْيَانِهِنَّ مِنْ أَجْلِ أَزْوَاجِهِنَّ مِنَ الْمُشْرِكِينَ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ فِي ذَلِكَ ‏\{‏ وَالْمُحْصَنَاتُ مِنَ النِّسَاءِ إِلاَّ مَا مَلَكَتْ أَيْمَانُكُمْ‏\}‏ أَىْ فَهُنَّ لَكُمْ حَلاَلٌ إِذَا انْقَضَتْ عِدَّتُهُنَّ ‏.‏\hadithno{3608}\hadithtrans{Abu Sa'id al-Khudri (Allah her pleased with him) reported that at the Battle of Hanain Allah's Messenger (ﷺ) sent an army to Autas and encountered the enemy and fought with them. Having overcome them and taken them captives, the Companions of Allah's Messenger (may peace te upon him) seemed to refrain from having intercourse with captive women because of their husbands being polytheists. Then Allah, Most High, sent down regarding that:" And women already married, except those whom your right hands possess (iv. 24)" (i. e. they were lawful for them when their 'Idda period came to an end)}}
\hadithdefcmd{muslim}{3609}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالُوا حَدَّثَنَا عَبْدُ، الأَعْلَى عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَبِي الْخَلِيلِ، أَنَّ أَبَا عَلْقَمَةَ الْهَاشِمِيَّ، حَدَّثَ أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ حَدَّثَهُمْ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم بَعَثَ يَوْمَ حُنَيْنٍ سَرِيَّةً ‏.‏ بِمَعْنَى حَدِيثِ يَزِيدَ بْنِ زُرَيْعٍ غَيْرَ أَنَّهُ قَالَ إِلاَّ مَا مَلَكَتْ أَيْمَانُكُمْ مِنْهُنَّ فَحَلاَلٌ لَكُمْ وَلَمْ يَذْكُرْ إِذَا انْقَضَتْ عِدَّتُهُنَّ ‏\hadithno{3609}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) reported that Allah's Apostle (ﷺ) sent a small army. The rest of the hadith is the same except this that he said:Except what your right hands possess out of them are lawful for you; and he did not mention" when their 'idda period comes to an end}}
\hadithdefcmd{muslim}{3610}{وَحَدَّثَنِيهِ يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{3610}\hadithtrans{Likewise, the above hadith has been narrated through another chain}}
\hadithdefcmd{muslim}{3611}{وَحَدَّثَنِيهِ يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَبِي الْخَلِيلِ، عَنْ أَبِي سَعِيدٍ، قَالَ أَصَابُوا سَبْيًا يَوْمَ أَوْطَاسٍ لَهُنَّ أَزْوَاجٌ فَتَخَوَّفُوا فَأُنْزِلَتْ هَذِهِ الآيَةُ ‏\{‏ وَالْمُحْصَنَاتُ مِنَ النِّسَاءِ إِلاَّ مَا مَلَكَتْ أَيْمَانُكُمْ‏\}‏ ‏.‏\hadithno{3611}\hadithtrans{This hadith has been reported on the authority of AbuSa'id (al-Khudri) (Allah be pleased with him) through another chain of transmitters and the words are:They took captives (women) on the day of Autas who had their husbands. They were afraid (to have sexual intercourse with them) when this verse was revealed:" And women already married except those whom you right hands posses" (iv)}}
\hadithdefcmd{muslim}{3612}{وَحَدَّثَنِي يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{3612}\hadithtrans{Qatada reported a hadith like this with the same chain of transmitters}}
\hadithdefcmd{muslim}{3613}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتِ اخْتَصَمَ سَعْدُ بْنُ أَبِي وَقَّاصٍ وَعَبْدُ بْنُ زَمْعَةَ فِي غُلاَمٍ فَقَالَ سَعْدٌ هَذَا يَا رَسُولَ اللَّهِ ابْنُ أَخِي عُتْبَةَ بْنِ أَبِي وَقَّاصٍ عَهِدَ إِلَىَّ أَنَّهُ ابْنُهُ انْظُرْ إِلَى شَبَهِهِ وَقَالَ عَبْدُ بْنُ زَمْعَةَ هَذَا أَخِي يَا رَسُولَ اللَّهِ وُلِدَ عَلَى فِرَاشِ أَبِي مِنْ وَلِيدَتِهِ فَنَظَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى شَبَهِهِ فَرَأَى شَبَهًا بَيِّنًا بِعُتْبَةَ فَقَالَ ‏"‏ هُوَ لَكَ يَا عَبْدُ الْوَلَدُ لِلْفِرَاَشِ وَلِلْعَاهِرِ الْحَجَرُ وَاحْتَجِبِي مِنْهُ يَا سَوْدَةُ بِنْتَ زَمْعَةَ ‏"‏ ‏.‏ قَالَتْ فَلَمْ يَرَ سَوْدَةَ قَطُّ وَلَمْ يَذْكُرْ مُحَمَّدُ بْنُ رُمْحٍ قَوْلَهُ ‏"‏ يَا عَبْدُ ‏"‏ ‏.‏\hadithno{3613}\hadithtrans{A'isha (Allah be pleased with her) reported:Sa'd b. Abu Waqqas and Abd b. Zam'a (Allah be pleased with them) disputed with each other over a young boy. Sa'd said: Messenger of Allah, he is the son of my brother 'Utba b. Abu Waqqas as he made it explicit that he was his son. Look at his resemblance. Abd b. Zam'a said Messenger of Allah, he is my brother as he was born on the bed of my father from his slave-girl. Allah's Messenger (ﷺ) looked at his resemblance and found a clear resemblance with 'Utba. (But) he said: "He is yours O 'Abd (b. Zam'a), for the child is to be attributed to one on whose bed it is born, and stoning for a fornicator. Sauda bint Zam'a, O you should observe veil from him." So he did not see Sauda at all. Muhammad b. Rumh did not make a mention (of the words): "O Abd}}
\hadithdefcmd{muslim}{3614}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ قَالُوا حَدَّثَنَا سُفْيَانُ، بْنُ عُيَيْنَةَ ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ غَيْرَ أَنَّ مَعْمَرًا وَابْنَ عُيَيْنَةَ فِي حَدِيثِهِمَا ‏"‏ الْوَلَدُ لِلْفِرَاشِ ‏"‏ ‏.‏ وَلَمْ يَذْكُرَا ‏"‏ وَلِلْعَاهِرِ الْحَجَرُ ‏"‏ ‏.‏\hadithno{3614}\hadithtrans{A hadith like this is narrated on the authority of Ibn 'Uyaiyna and Ma'mar (and the words are):The child is attributed to him on whose bed he is born; but they did not mention this:" For a fornicator there is stoning}}
\hadithdefcmd{muslim}{3615}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، - قَالَ ابْنُ رَافِعٍ - حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْوَلَدُ لِلْفِرَاشِ وَلِلْعَاهِرِ الْحَجَرُ ‏"‏ ‏.‏\hadithno{3615}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:The child is to be attributed to one on whose bed he is born, and for a fornicator there is stoning}}
\hadithdefcmd{muslim}{3616}{وَحَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَزُهَيْرُ بْنُ حَرْبٍ، وَعَبْدُ الأَعْلَى بْنُ حَمَّادٍ، وَعَمْرٌو النَّاقِدُ، قَالُوا حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، أَمَّا ابْنُ مَنْصُورٍ فَقَالَ عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، وَأَمَّا، عَبْدُ الأَعْلَى فَقَالَ عَنْ أَبِي سَلَمَةَ، أَوْ عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، وَقَالَ، زُهَيْرٌ عَنْ سَعِيدٍ، أَوْ عَنْ أَبِي سَلَمَةَ، أَحَدُهُمَا أَوْ كِلاَهُمَا عَنْ أَبِي هُرَيْرَةَ، وَقَالَ، عَمْرٌو حَدَّثَنَا سُفْيَانُ، مَرَّةً عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، وَأَبِي، سَلَمَةَ وَمَرَّةً عَنْ سَعِيدٍ، أَوْ أَبِي سَلَمَةَ وَمَرَّةً عَنْ سَعِيدٍ، عَنْ أَبِي، هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ مَعْمَرٍ ‏.‏\hadithno{3616}\hadithtrans{A hadith like this is narrated on the authority of Abu Huraira}}
\hadithdefcmd{muslim}{3617}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ رُمْحٍ، قَالاَ أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ، سَعِيدٍ حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ عَلَىَّ مَسْرُورًا تَبْرُقُ أَسَارِيرُ وَجْهِهِ فَقَالَ ‏ "‏ أَلَمْ تَرَىْ أَنَّ مُجَزِّزًا نَظَرَ آنِفًا إِلَى زَيْدِ بْنِ حَارِثَةَ وَأُسَامَةَ بْنِ زَيْدٍ فَقَالَ إِنَّ بَعْضَ هَذِهِ الأَقْدَامِ لَمِنْ بَعْضٍ ‏"‏ ‏.‏\hadithno{3617}\hadithtrans{A'isha (Allah be pleased with her) reported:Allah's Messenger (ﷺ) visited me looking pleased as if his face was glistening and said: Did you see that Mujazziz cast a glance at Zaid b. Haritha and Usama b. Zaid, and (then) said: Some (of the features) of their feet are found in the others?}}
\hadithdefcmd{muslim}{3618}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ - وَاللَّفْظُ لِعَمْرٍو - قَالُوا حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ مَسْرُورًا فَقَالَ ‏ "‏ يَا عَائِشَةُ أَلَمْ تَرَىْ أَنَّ مُجَزِّزًا الْمُدْلِجِيَّ دَخَلَ عَلَىَّ فَرَأَى أُسَامَةَ وَزَيْدًا وَعَلَيْهِمَا قَطِيفَةٌ قَدْ غَطَّيَا رُءُوسَهُمَا وَبَدَتْ أَقْدَامُهُمَا فَقَالَ إِنَّ هَذِهِ الأَقْدَامَ بَعْضُهَا مِنْ بَعْضٍ ‏"‏ ‏.‏\hadithno{3618}\hadithtrans{A'isha (Allah be pleased with her) reported:One day Allah's Apostle (ﷺ) visited me looking pleased and he said: 'A'isha, don't you see Mujazziz al-Mudliji? (He) entered (my house) and saw Usama and Zaid with a rug over them covering their heads, but their feet appeared, and (he) said: These feet are related to one another}}
\hadithdefcmd{muslim}{3619}{وَحَدَّثَنَاهُ مَنْصُورُ بْنُ أَبِي مُزَاحِمٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَ قَائِفٌ وَرَسُولُ اللَّهِ صلى الله عليه وسلم شَاهِدٌ وَأُسَامَةُ بْنُ زَيْدٍ وَزَيْدُ بْنُ حَارِثَةَ مُضْطَجِعَانِ فَقَالَ إِنَّ هَذِهِ الأَقْدَامَ بَعْضُهَا مِنْ بَعْضٍ ‏.‏ فَسُرَّ بِذَلِكَ النَّبِيُّ صلى الله عليه وسلم وَأَعْجَبَهُ وَأَخْبَرَ بِهِ عَائِشَةَ ‏.‏\hadithno{3619}\hadithtrans{A'isha (Allah be pleased with her) reported:A physiognomist visited (our house) and Allah's Messenger (ﷺ) was present, and Usama b. Zaid and Zaid b. Haritha were both lying asleep, and he (the physiognomist), said: These feet are related to one another. Allah's Apostle (ﷺ) was pleased to hear this, and he was happy and informed 'A'isha (Allah be pleased with her) about it}}
\hadithdefcmd{muslim}{3620}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنَا عَبْدُ بْنُ، حُمَيْدٍ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، وَابْنُ، جُرَيْجٍ كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ بِمَعْنَى حَدِيثِهِمْ ‏.‏ وَزَادَ فِي حَدِيثِ يُونُسَ وَكَانَ مُجَزِّزٌ قَائِفًا ‏.‏\hadithno{3620}\hadithtrans{A hadith like this has been narrated on the authority of Zuhri and Yunus said:Mujazziz was a physiognomist}}
\hadithdefcmd{muslim}{3621}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ حَاتِمٍ، وَيَعْقُوبُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالُوا حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، عَنْ مُحَمَّدِ بْنِ أَبِي بَكْرٍ، عَنْ عَبْدِ الْمَلِكِ، بْنِ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ عَنْ أَبِيهِ، عَنْ أُمِّ سَلَمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا تَزَوَّجَ أُمَّ سَلَمَةَ أَقَامَ عِنْدَهَا ثَلاَثًا وَقَالَ ‏ "‏ إِنَّهُ لَيْسَ بِكِ عَلَى أَهْلِكِ هَوَانٌ إِنْ شِئْتِ سَبَّعْتُ لَكِ وَإِنْ سَبَّعْتُ لَكِ سَبَّعْتُ لِنِسَائِي ‏"‏ ‏\hadithno{3621}\hadithtrans{Abd al-Malik b. Abu Bakr b. Abd al-Rahman b. al-Harith b. Hisham reported on the authority of his father from Umm Salama (Allah be pleased with her) that when Allah's Messenger (ﷺ) married Umm Salama, he stayed with her for three nights, and said:There is no lack of estimation on the part of your husband for you. If you wish I can stay with you for a week, but in case I stay with you for a week, then I shall have to stay for a week with all my wives}}
\hadithdefcmd{muslim}{3622}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَبْدِ، الْمَلِكِ بْنِ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ ‏\{‏ عَنْ أَبِيهِ، ‏\}‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ تَزَوَّجَ أَمَّ سَلَمَةَ وَأَصْبَحَتْ عِنْدَهُ قَالَ لَهَا ‏ "‏ لَيْسَ بِكِ عَلَى أَهْلِكِ هَوَانٌ إِنْ شِئْتِ سَبَّعْتُ عِنْدَكِ وَإِنْ شِئْتِ ثَلَّثْتُ ثُمَّ دُرْتُ ‏"‏ ‏.‏ قَالَتْ ثَلِّثْ ‏.‏\hadithno{3622}\hadithtrans{Ibn Abu Bakr b. Abd al-Rahman reported that when Allah's Messenger (ﷺ) married Umm Salama and she stayed with him (during the night), and it was dawn, he (the Holy Prophet) said to her:There is no lack of estimation for you on the part of your husband. So if you desire I can spend a week with you, and if you like I may spend three (nights). and then I will visit you in turn. She said: Spend three (nights)}}
\hadithdefcmd{muslim}{3623}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ عَبْدِ، الرَّحْمَنِ بْنِ حُمَيْدٍ عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ تَزَوَّجَ أُمَّ سَلَمَةَ فَدَخَلَ عَلَيْهَا فَأَرَادَ أَنْ يَخْرُجَ أَخَذَتْ بِثَوْبِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنْ شِئْتِ زِدْتُكِ وَحَاسَبْتُكِ بِهِ لِلْبِكْرِ سَبْعٌ وَلِلثَّيِّبِ ثَلاَثٌ‏"‏ ‏.‏\hadithno{3623}\hadithtrans{Abu Bakr b. 'Abd al-Rahman reported that when Allah's Messenger (ﷺ) married Umm Salama and he visited her, and when he intended to come out, she caught hold of his cloth. whereupon Allah's Messenger (ﷺ) said:If you so desire, I can extend the time (of my stay) with you, but then I shall have to calculate the time (that I stay with you and shall have to spend the same time with other wives). For the virgin woman, (her husband has to stay with her) for a week, and for the woman previously married it is three days}}
\hadithdefcmd{muslim}{3624}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو ضَمْرَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حُمَيْدٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{3624}\hadithtrans{A hadith like this has been narrated on the authority of Ibn Humaid}}
\hadithdefcmd{muslim}{3625}{حَدَّثَنِي أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا حَفْصٌ، - يَعْنِي ابْنَ غِيَاثٍ - عَنْ عَبْدِ، الْوَاحِدِ بْنِ أَيْمَنَ عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ أُمِّ سَلَمَةَ، ذَكَرَ أَنَّصلى الله عليه وسلم تَزَوَّجَهَا وَذَكَرَ أَشْيَاءَ هَذَا فِيهِ قَالَ ‏ "‏ إِنْ شِئْتِ أَنْ أُسَبِّعَ لَكِ وَأُسَبِّعَ لِنِسَائِي وَإِنْ سَبَّعْتُ لَكِ سَبَّعْتُ لِنِسَائِي ‏"‏ ‏.‏\hadithno{3625}\hadithtrans{Umm Salama (Allah be pleased with her) reported that Allah's Messenger (ﷺ) married her, and he (the narrator) made mention of so many things in this connection (and one of them was this) that he said:If you desire that I spend a week with you, I shall have to spend a week with my (other) wives, and if spend a week with you, I shall have to spend a week with my (other) wives}}
\hadithdefcmd{muslim}{3626}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ خَالِدٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسِ بْنِ، مَالِكٍ قَالَ إِذَا تَزَوَّجَ الْبِكْرَ عَلَى الثَّيِّبِ أَقَامَ عِنْدَهَا سَبْعًا وَإِذَا تَزَوَّجَ الثَّيِّبَ عَلَى الْبِكْرِ أَقَامَ عِنْدَهَا ثَلاَثًا ‏.‏ قَالَ خَالِدٌ وَلَوْ قُلْتُ إِنَّهُ رَفَعَهُ لَصَدَقْتُ وَلَكِنَّهُ قَالَ السُّنَّةُ كَذَلِكَ ‏.‏\hadithno{3626}\hadithtrans{Anas b. Malik reported:When anyone who has already a wife marries virgin, he should stay with her for seven nights (and then turn to his other wife), but when anyone having a virgin with him (as his wife) marries a woman who has been previously married he should stay with her for three nights. Khalid (one of the narrators) said. If I were to say that it could be directly traced to the Prophet (ﷺ). I would have told the truth, but he (Hadrat Anas) said: Such is the tradition}}
\hadithdefcmd{muslim}{3627}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَيُّوبَ، وَخَالِدٍ، الْحَذَّاءِ عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، قَالَ مِنَ السُّنَّةِ أَنْ يُقِيمَ، عِنْدَ الْبِكْرِ سَبْعًا ‏.‏ قَالَ خَالِدٌ وَلَوْ شِئْتُ قُلْتُ رَفَعَهُ إِلَى النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3627}\hadithtrans{Abu Qilaba reported on the authority of Anas:It is the Sunnah to stay with a virgin (after having married her) for a week. Khalid (one of the narrators) said: If wish I can say that it can be traced up to the Prophet (ﷺ)}}
\hadithdefcmd{muslim}{3628}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ بْنُ سَوَّارٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ كَانَ لِلنَّبِيِّ صلى الله عليه وسلم تِسْعُ نِسْوَةٍ فَكَانَ إِذَا قَسَمَ بَيْنَهُنَّ لاَ يَنْتَهِي إِلَى الْمَرْأَةِ الأُولَى إِلاَّ فِي تِسْعٍ فَكُنَّ يَجْتَمِعْنَ كُلَّ لَيْلَةٍ فِي بَيْتِ الَّتِي يَأْتِيهَا فَكَانَ فِي بَيْتِ عَائِشَةَ فَجَاءَتْ زَيْنَبُ فَمَدَّ يَدَهُ إِلَيْهَا فَقَالَتْ هَذِهِ زَيْنَبُ ‏.‏ فَكَفَّ النَّبِيُّ صلى الله عليه وسلم يَدَهُ ‏.‏ فَتَقَاوَلَتَا حَتَّى اسْتَخَبَتَا وَأُقِيمَتِ الصَّلاَةُ فَمَرَّ أَبُو بَكْرٍ عَلَى ذَلِكَ فَسَمِعَ أَصْوَاتَهُمَا فَقَالَ اخْرُجْ يَا رَسُولَ اللَّهِ إِلَى الصَّلاَةِ وَاحْثُ فِي أَفْوَاهِهِنَّ التُّرَابَ ‏.‏ فَخَرَجَ النَّبِيُّ صلى الله عليه وسلم فَقَالَتْ عَائِشَةُ الآنَ يَقْضِي النَّبِيُّ صلى الله عليه وسلم صَلاَتَهُ فَيَجِيءُ أَبُو بَكْرٍ فَيَفْعَلُ بِي وَيَفْعَلُ ‏.‏ فَلَمَّا قَضَى النَّبِيُّ صلى الله عليه وسلم صَلاَتَهُ أَتَاهَا أَبُو بَكْرٍ فَقَالَ لَهَا قَوْلاً شَدِيدًا وَقَالَ أَتَصْنَعِينَ هَذَا\hadithno{3628}\hadithtrans{Anas (Allah be pleased with him) reported that Allah's Apostle (ﷺ) had nine wives. So when he divided (his stay) with them, the turn of the first wife did not come but on the ninth (day). They (all the wives) used to gather every night in the house of one where he had to come (and stay that night). It was (the night when he had to stay) in the house of 'A'isha (Allah be pleased with her), when Zainab came there. He (the Holy Prophet) stretched his hand towards her (Zainab), whereupon she ('A'isha) said:It is Zainab. Allah's Apostle (ﷺ) withdrew his hand. There was an altercation between the two until their voices became loud (and it was at that time) when Iqama was pronounced for prayer. There happened to come Abu Bakr and he heard their voices and said: Messenger of Allah, (kindly) come for prayer, and throw dust in their mouths. So the Prophet (ﷺ) went out. 'A'isha said: When Allah's Apostle (ﷺ) would finish his prayer there would also come Abu Bakr and he would do as he does (on such occasions, i.e. reprimanding). When Allah's Apostle (ﷺ) had finished his prayer, there came to her Abu Bakr, and spoke to her ('A'isha) in stern words and said: Do you behave like this?}}
\hadithdefcmd{muslim}{3629}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ مَا رَأَيْتُ امْرَأَةً أَحَبَّ إِلَىَّ أَنْ أَكُونَ فِي مِسْلاَخِهَا مِنْ سَوْدَةَ بِنْتِ زَمْعَةَ مِنِ امْرَأَةٍ فِيهَا حِدَّةٌ قَالَتْ فَلَمَّا كَبِرَتْ جَعَلَتْ يَوْمَهَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم لِعَائِشَةَ قَالَتْ يَا رَسُولَ اللَّهِ قَدْ جَعَلْتُ يَوْمِي مِنْكَ لِعَائِشَةَ ‏.‏ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْسِمُ لِعَائِشَةَ يَوْمَيْنِ يَوْمَهَا وَيَوْمَ سَوْدَةَ ‏.‏\hadithno{3629}\hadithtrans{A'isha (Allah be pleased with her) reported:Never did I find any woman more loving to me than Sauda bint Zam'a. I wished I could be exactly like her who was passionate. As she became old, she had made over her day (which she had to spend) with Allah's Messenger (ﷺ) to 'A'isha. She said: I have made over my day with you to 'A'isha. So Allah's Messenger (ﷺ) allotted two days to 'A'isha, her own day (when it was her turn) and that of Sauda}}
\hadithdefcmd{muslim}{3630}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُقْبَةُ بْنُ خَالِدٍ، ح وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا الأَسْوَدُ بْنُ عَامِرٍ، حَدَّثَنَا زُهَيْرٌ، ح وَحَدَّثَنَا مُجَاهِدُ بْنُ مُوسَى، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا شَرِيكٌ، كُلُّهُمْ عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ أَنَّ سَوْدَةَ، لَمَّا كَبِرَتْ ‏.‏ بِمَعْنَى حَدِيثِ جَرِيرٍ وَزَادَ فِي حَدِيثِ شَرِيكٍ قَالَتْ وَكَانَتْ أَوَّلَ امْرَأَةٍ تَزَوَّجَهَا بَعْدِي ‏.‏\hadithno{3630}\hadithtrans{A hadith like this has been transmitted on the authority of Hisham with the same chain of narrators (and the words are):When Sauda became old (the rest of the hadith is the same) and in the narration of Sharik there is an addition (of these words:" She was the first woman whom he (Allah's Apostle) married after me}}
\hadithdefcmd{muslim}{3631}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَغَارُ عَلَى اللاَّتِي وَهَبْنَ أَنْفُسَهُنَّ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَأَقُولُ وَتَهَبُ الْمَرْأَةُ نَفْسَهَا فَلَمَّا أَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ تُرْجِي مَنْ تَشَاءُ مِنْهُنَّ وَتُؤْوِي إِلَيْكَ مَنْ تَشَاءُ وَمَنِ ابْتَغَيْتَ مِمَّنْ عَزَلْتَ‏\}‏ قَالَتْ قُلْتُ وَاللَّهِ مَا أَرَى رَبَّكَ إِلاَّ يُسَارِعُ لَكَ فِي هَوَاكَ\hadithno{3631}\hadithtrans{A'isha (Allah be pleased with her) reported:I felt jealous of the women who offered themselves to Allah's Messenger (ﷺ) and said: Then when Allah, the Exalted and Glorious, revealed this:" You may defer any one of them you wish, and take to yourself any you wish; and if you desire any you have set aside (no sin is chargeable to you)" (xxxiii. 51), I ('A'isha.) said: It seems to me that your Lord hastens to satisfy your desire}}
\hadithdefcmd{muslim}{3632}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا كَانَتْ تَقُولُ أَمَا تَسْتَحْيِي امْرَأَةٌ تَهَبُ نَفْسَهَا لِرَجُلٍ حَتَّى أَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ تُرْجِي مَنْ تَشَاءُ مِنْهُنَّ وَتُؤْوِي إِلَيْكَ مَنْ تَشَاءُ‏\}‏ فَقُلْتُ إِنَّ رَبَّكَ لَيُسَارِعُ لَكَ فِي هَوَاكَ.‏\hadithno{3632}\hadithtrans{Hisham reported on the authority of his father that 'A'isha (Allah be pleased with her) used to say:Does the woman not feel shy of offering herself to a man? Then Allah the Exalted and Glorious revealed this verse:" You may defer any of them you wish and take to yourself any you wish." I ('A'isha said): It seems to me that your Lord hastens to satisfy your desire}}
\hadithdefcmd{muslim}{3633}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ حَاتِمٍ، قَالَ مُحَمَّدُ بْنُ حَاتِمٍ حَدَّثَنَا مُحَمَّدُ، بْنُ بَكْرٍ أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَطَاءٌ، قَالَ حَضَرْنَا مَعَ ابْنِ عَبَّاسٍ جَنَازَةَ مَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم بِسَرِفَ فَقَالَ ابْنُ عَبَّاسٍ هَذِهِ زَوْجُ النَّبِيِّ صلى الله عليه وسلم فَإِذَا رَفَعْتُمْ نَعْشَهَا فَلاَ تُزَعْزِعُوا وَلاَ تُزَلْزِلُوا وَارْفُقُوا فَإِنَّهُ كَانَ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم تِسْعٌ فَكَانَ يَقْسِمُ لِثَمَانٍ وَلاَ يَقْسِمُ لِوَاحِدَةٍ ‏.‏ قَالَ عَطَاءٌ الَّتِي لاَ يَقْسِمُ لَهَا صَفِيَّةُ بِنْتُ حُيَىِّ بْنِ أَخْطَبَ ‏.‏\hadithno{3633}\hadithtrans{Ata related that when they were with Ibn 'Abbas (Allah be pleased with them) at the funeral of Maimuna In Sarif, Ibn 'Abbas (Allah be pleased with them) said:This is the wife of Allah's Apostle (ﷺ) ; so when you lift her bier, do not shake her or disturb her, but be gentle, for Allah's Messenger (ﷺ) had nine wives, with eight of whom he shared his time, but to one of them, he did not allot a share. 'Ati said: The one to whom he did not allot a share of time was Safiyya, daughter of Huyayy b. Akhtab}}
\hadithdefcmd{muslim}{3634}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، جَمِيعًا عَنْ عَبْدِ الرَّزَّاقِ، عَنِ ابْنِ جُرَيْجٍ، بِهَذَا الإِسْنَادِ وَزَادَ قَالَ عَطَاءٌ كَانَتْ آخِرَهُنَّ مَوْتًا مَاتَتْ بِالْمَدِينَةِ ‏.‏\hadithno{3634}\hadithtrans{Ibn Juraij narrated a hadith with the same chain of transmitters, and she (Hadrat Maimuna) was the last of them to die at Medina}}
\hadithdefcmd{muslim}{3635}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالُوا حَدَّثَنَا يَحْيَى، بْنُ سَعِيدٍ عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تُنْكَحُ الْمَرْأَةُ لأَرْبَعٍ لِمَالِهَا وَلِحَسَبِهَا وَلِجَمَالِهَا وَلِدِينِهَا فَاظْفَرْ بِذَاتِ الدِّينِ تَرِبَتْ يَدَاكَ ‏"‏ ‏.‏\hadithno{3635}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:A woman may be married for four reasons: for her property, her status. her beauty and her religion, so try to get one who is religious, may your hand be besmeared with dust}}
\hadithdefcmd{muslim}{3636}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، أَخْبَرَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ، قَالَ تَزَوَّجْتُ امْرَأَةً فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَقِيتُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ يَا جَابِرُ تَزَوَّجْتَ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ بِكْرٌ أَمْ ثَيِّبٌ ‏"‏ ‏.‏ قُلْتُ ثَيِّبٌ ‏.‏ قَالَ ‏"‏ فَهَلاَّ بِكْرًا تُلاَعِبُهَا ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ لِي أَخَوَاتٍ فَخَشِيتُ أَنْ تَدْخُلَ بَيْنِي وَبَيْنَهُنَّ ‏.‏ قَالَ ‏"‏ فَذَاكَ إِذًا ‏.‏ إِنَّ الْمَرْأَةَ تُنْكَحُ عَلَى دِينِهَا وَمَالِهَا وَجَمَالِهَا فَعَلَيْكَ بِذَاتِ الدِّينِ تَرِبَتْ يَدَاكَ ‏"‏ ‏.‏\hadithno{3636}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported:I married a woman during the lifetime of Allah's Messenger (may peace be. upon him). I met the Messenger of Allah (ﷺ), whereupon he said: Jabir, have you married? I said: Yes. He said: A virgin or one previously marrried? I said: With due previously married, whereupon he said: Why did you not marry a virgin with whom you could sport? I said: Allah's Messenger, I have sisters; I was afraid that she might intervene between me and them, whereupon he said: Well and good, if it is so. A woman is married for four reasons, for her religion, her property, her status, her beauty, so you should choose one with religion. May your hands cleave to dust}}
\hadithdefcmd{muslim}{3637}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَارِبٍ، عَنْ جَابِرِ بْنِ، عَبْدِ اللَّهِ قَالَ تَزَوَّجْتُ امْرَأَةً فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ تَزَوَّجْتَ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ أَبِكْرًا أَمْ ثَيِّبًا ‏"‏ ‏.‏ قُلْتُ ثَيِّبًا ‏.‏ قَالَ ‏"‏ فَأَيْنَ أَنْتَ مِنَ الْعَذَارَى وَلِعَابِهَا ‏"‏ ‏.‏ قَالَ شُعْبَةُ فَذَكَرْتُهُ لِعَمْرِو بْنِ دِينَارٍ فَقَالَ قَدْ سَمِعْتُهُ مِنْ جَابِرٍ وَإِنَّمَا قَالَ ‏"‏ فَهَلاَّ جَارِيَةً تُلاَعِبُهَا وَتُلاَعِبُكَ ‏"‏\hadithno{3637}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported:I married a woman, whereupon Allah's Messenger (ﷺ) said to me: Have you married? I said: Yes. He said: Is it a virgin or a previously married one (widow or divorced)? I said: With a previously married one, whereupon he said: Where had you been (away) from the amusements of virgins? Shu'ba said: I made a mention of it to 'Amr b. Dinar and he said: I too heard from Jabir making mention of that (that Allah's Apostle) said: Why didn't you marry a girl, so that you might sport with her and she might sport with you?}}
\hadithdefcmd{muslim}{3638}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو الرَّبِيعِ الزَّهْرَانِيُّ، قَالَ يَحْيَى أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ، هَلَكَ وَتَرَكَ تِسْعَ بَنَاتٍ - أَوْ قَالَ سَبْعَ - فَتَزَوَّجْتُ امْرَأَةً ثَيِّبًا فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا جَابِرُ تَزَوَّجْتَ ‏"‏ ‏.‏ قَالَ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ فَبِكْرٌ أَمْ ثَيِّبٌ ‏"‏ ‏.‏ قَالَ قُلْتُ بَلْ ثَيِّبٌ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ فَهَلاَّ جَارِيَةً تُلاَعِبُهَا وَتُلاَعِبُكَ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ تُضَاحِكُهَا وَتُضَاحِكُكَ ‏"‏ ‏.‏ قَالَ قُلْتُ لَهُ إِنَّ عَبْدَ اللَّهِ هَلَكَ وَتَرَكَ تِسْعَ بَنَاتٍ - أَوْ سَبْعَ - وَإِنِّي كَرِهْتُ أَنْ آتِيَهُنَّ أَوْ أَجِيئَهُنَّ بِمِثْلِهِنَّ فَأَحْبَبْتُ أَنْ أَجِيءَ بِامْرَأَةٍ تَقُومُ عَلَيْهِنَّ وَتُصْلِحُهُنَّ ‏.‏ قَالَ ‏"‏ فَبَارَكَ اللَّهُ لَكَ ‏"‏ ‏.‏ أَوْ قَالَ لِي خَيْرًا وَفِي رِوَايَةِ أَبِي الرَّبِيعِ ‏"‏ تُلاَعِبُهَا وَتُلاَعِبُكَ وَتُضَاحِكُهَا وَتُضَاحِكُكَ ‏"‏ ‏.‏\hadithno{3638}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported:'Abdullah died and he left (behind him) nine or seven daughters. I married a woman who had been previously married. Allah's Messenger (ﷺ) said to me: Jabir, have you married? I said: Yes. He (again) said: A virgin or one previously married? I said: Messenger of Allah, with one who was previously married, whereupon he said: Why didn't you marry a young girl so that you could sport with her and she could sport with you, or you could amuse with her and she could amuse with you? I said to him: 'Abdullah died (he fell as martyr in Uhud) and left nine or seven daughters behind him; I, therefore, did not approve of the idea that I should bring a (girl) like them, but I preferred to bring a woman who should look after them and teach them good manners, whereupon he (Allah's Messenger) said: May Allah bless you, or he supplicated (for the) good (to be) conferred on me (by Allah)}}
\hadithdefcmd{muslim}{3639}{وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ نَكَحْتَ يَا جَابِرُ ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ إِلَى قَوْلِهِ امْرَأَةً تَقُومُ عَلَيْهِنَّ وَتَمْشُطُهُنَّ قَالَ ‏"‏ أَصَبْتَ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ مَا بَعْدَهُ ‏.‏\hadithno{3639}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported Allah's Messenger (ﷺ) said to me:Jabir, have you married? The rest of the hadith is the same up to (the words):" The woman would look after them and comb them." He (Allah's Messenger), said: You did well. But no mention is made of the subsequent portion}}
\hadithdefcmd{muslim}{3640}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ سَيَّارٍ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ، اللَّهِ قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزَاةٍ فَلَمَّا أَقْبَلْنَا تَعَجَّلْتُ عَلَى بَعِيرٍ لِي قَطُوفٍ فَلَحِقَنِي رَاكِبٌ خَلْفِي فَنَخَسَ بَعِيرِي بِعَنَزَةٍ كَانَتْ مَعَهُ فَانْطَلَقَ بَعِيرِي كَأَجْوَدِ مَا أَنْتَ رَاءٍ مِنَ الإِبِلِ فَالْتَفَتُّ فَإِذَا أَنَا بِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا يُعْجِلُكَ يَا جَابِرُ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي حَدِيثُ عَهْدٍ بِعُرْسٍ ‏.‏ فَقَالَ ‏"‏ أَبِكْرًا تَزَوَّجْتَهَا أَمْ ثَيِّبًا ‏"‏ ‏.‏ قَالَ قُلْتُ بَلْ ثَيِّبًا ‏.‏ قَالَ ‏"‏ هَلاَّ جَارِيَةً تُلاَعِبُهَا وَتُلاَعِبُكَ ‏"‏ ‏.‏ قَالَ فَلَمَّا قَدِمْنَا الْمَدِينَةَ ذَهَبْنَا لِنَدْخُلَ فَقَالَ ‏"‏ أَمْهِلُوا حَتَّى نَدْخُلَ لَيْلاً - أَىْ عِشَاءً - كَىْ تَمْتَشِطَ الشَّعِثَةُ وَتَسْتَحِدَّ الْمُغِيبَةُ ‏"‏ ‏.‏ قَالَ وَقَالَ ‏"‏ إِذَا قَدِمْتَ فَالْكَيْسَ الْكَيْسَ ‏"‏ ‏.‏\hadithno{3640}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported:We were with Allah's Messenger (ﷺ) in an expedition. When we returned I urged my camel to move quickly as it was slow. There met me a rider from behind me and he goaded it with an iron-tipped stick which he had with him. My camel moved forward like the best that you have ever seen. As I turned (my face) I found him to be Allah's Messenger (ﷺ) He said: Jabir, what hastens you? I said: Messenger of Allah, I am newly wedded. whereupon he said: Is it a virgin that you have married or one previously married? I said: With one previously married. He said: Why not a young girl so that you could play with her and she could play with you? Then when we arrived at and were about to enter Medina he said: Wait, so that we may enter by night (i. e. in the evening) in order that the woman with dishevelled hair may comb it, and the woman whose husband had been away may get herself clean; and when you enter (then you have the) enjoyment (of tho wife's company)}}
\hadithdefcmd{muslim}{3641}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، - يَعْنِي ابْنَ عَبْدِ الْمَجِيدِ الثَّقَفِيَّ - حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ خَرَجْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزَاةٍ فَأَبْطَأَ بِي جَمَلِي فَأَتَى عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ لِي ‏"‏ يَا جَابِرُ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ مَا شَأْنُكَ ‏"‏ ‏.‏ قُلْتُ أَبْطَأَ بِي جَمَلِي وَأَعْيَا فَتَخَلَّفْتُ ‏.‏ فَنَزَلَ فَحَجَنَهُ بِمِحْجَنِهِ ثُمَّ قَالَ ‏"‏ ارْكَبْ ‏"‏ ‏.‏ فَرَكِبْتُ فَلَقَدْ رَأَيْتُنِي أَكُفُّهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَتَزَوَّجْتَ ‏"‏ ‏.‏ فَقُلْتُ نَعَمْ ‏.‏ فَقَالَ ‏"‏ أَبِكْرًا أَمْ ثَيِّبًا ‏"‏ ‏.‏ فَقُلْتُ بَلْ ثَيِّبٌ ‏.‏ قَالَ ‏"‏ فَهَلاَّ جَارِيَةً تُلاَعِبُهَا وَتُلاَعِبُكَ ‏"‏ ‏.‏ قُلْتُ إِنَّ لِي أَخَوَاتٍ فَأَحْبَبْتُ أَنْ أَتَزَوَّجَ امْرَأَةً تَجْمَعُهُنَّ وَتَمْشُطُهُنَّ وَتَقُومُ عَلَيْهِنَّ ‏.‏ قَالَ ‏"‏ أَمَا إِنَّكَ قَادِمٌ فَإِذَا قَدِمْتَ فَالْكَيْسَ الْكَيْسَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ أَتَبِيعُ جَمَلَكَ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ فَاشْتَرَاهُ مِنِّي بِأُوقِيَّةٍ ثُمَّ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدِمْتُ بِالْغَدَاةِ فَجِئْتُ الْمَسْجِدَ فَوَجَدْتُهُ عَلَى بَابِ الْمَسْجِدِ فَقَالَ ‏"‏ الآنَ حِينَ قَدِمْتَ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ فَدَعْ جَمَلَكَ وَادْخُلْ فَصَلِّ رَكْعَتَيْنِ ‏"‏ ‏.‏ قَالَ فَدَخَلْتُ فَصَلَّيْتُ ثُمَّ رَجَعْتُ فَأَمَرَ بِلاَلاً أَنْ يَزِنَ لِي أُوقِيَّةً فَوَزَنَ لِي بِلاَلٌ فَأَرْجَحَ فِي الْمِيزَانِ - قَالَ - فَانْطَلَقْتُ فَلَمَّا وَلَّيْتُ قَالَ ‏"‏ ادْعُ لِي جَابِرًا ‏"‏ ‏.‏ فَدُعِيتُ فَقُلْتُ الآنَ يَرُدُّ عَلَىَّ الْجَمَلَ ‏.‏ وَلَمْ يَكُنْ شَىْءٌ أَبْغَضَ إِلَىَّ مِنْهُ فَقَالَ ‏"‏ خُذْ جَمَلَكَ وَلَكَ ثَمَنُهُ ‏"‏ ‏.‏\hadithno{3641}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with him) reported:I went out with Allah's Messenger (ﷺ) on an expedition, but my camel delayed me. Allah's Messenger (ﷺ) came to me and said to me: Jabir, I said: Yes. Allah's Messenger, (here I am at your beck and call) He said: What is the matter with you? I said: My camel has delayed me and is tired, so I have lagged behind. He (the Holy Prophet) got down and goaded it with a crooked stick and then said: Mount it. So I mounted and (to my great surprise) I saw it (moving so quickly that) I had to restrain it (from going ahead of) Allah's Messenger (ﷺ). He (the Holy Prophet) (in the course of journey said to me): Have you married? I said: Yes. He (again) said: Is it with a virgin or one previously married? I said. With one previously married, whereupon he (again) said: Why not with a young girl with whom you could sport and she could have sported with you? I said: I have sisters, so I preferred to marry a woman who could keep them together (as one family). who could comb them and look after them. He said: You are about to go (to your house), and there you have the enjoyment (of the wife's company). He again said: Do you want to sell your camel? I said: Yes. So he bought it from me for one u'qiya (of silver), Then Allah's Messenger (ﷺ) arrived (at Medina) and I arrived in the evening. I went to the mosque and found him at the door of the mosque, and said: Is it now that you have arrived? I said: Yes, He said: Leave your camel, and enter (the mosque) and offer two rak'ahs. So I entered and offered two rak'ahs of prayer, and then returned. He (the Holy Prophet) then commanded Bilal to weigh out one 'uqiya (of silver) tor me. Bilal weighed that out for me (lowering the scale of) balance. So I proceeded and as I turned my back he said: Call for me, Jabir. So I was called back, and I said (to myself): He would return me the camel, and nothing was more displeasing to me than this (that after having received the price I should also get the camel). He said: Take your camel and keep its price with you, (also)}}
\hadithdefcmd{muslim}{3642}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ أَبِي، حَدَّثَنَا أَبُو نَضْرَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا فِي مَسِيرٍ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَا عَلَى نَاضِحٍ إِنَّمَا هُوَ فِي أُخْرَيَاتِ النَّاسِ - قَالَ - فَضَرَبَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَوْ قَالَ نَخَسَهُ - أُرَاهُ قَالَ - بِشَىْءٍ كَانَ مَعَهُ قَالَ فَجَعَلَ بَعْدَ ذَلِكَ يَتَقَدَّمُ النَّاسَ يُنَازِعُنِي حَتَّى إِنِّي لأَكُفُّهُ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَبِيعُنِيهِ بِكَذَا وَكَذَا وَاللَّهُ يَغْفِرُ لَكَ ‏"‏ ‏.‏ قَالَ قُلْتُ هُوَ لَكَ يَا نَبِيَّ اللَّهِ ‏.‏ قَالَ ‏"‏ أَتَبِيعُنِيهِ بِكَذَا وَكَذَا وَاللَّهُ يَغْفِرُ لَكَ ‏"‏ ‏.‏ قَالَ قُلْتُ هُوَ لَكَ يَا نَبِيَّ اللَّهِ ‏.‏ قَالَ وَقَالَ لِي ‏"‏ أَتَزَوَّجْتَ بَعْدَ أَبِيكَ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ ثَيِّبًا أَمْ بِكْرًا ‏"‏ ‏.‏ قَالَ قُلْتُ ثَيِّبًا ‏.‏ قَالَ ‏"‏ فَهَلاَّ تَزَوَّجْتَ بِكْرًا تُضَاحِكُكَ وَتُضَاحِكُهَا وَتُلاَعِبُكَ وَتُلاَعِبُهَا ‏"‏ ‏.‏ قَالَ أَبُو نَضْرَةَ فَكَانَتْ كَلِمَةً يَقُولُهَا الْمُسْلِمُونَ ‏.‏ افْعَلْ كَذَا وَكَذَا وَاللَّهُ يَغْفِرُ لَكَ ‏.‏\hadithno{3642}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported:We were with Allah's Messenger (ﷺ) in a journey, and I was riding a camel meant for carrying water and it lagged behind all persons. Allah's Messenger (ﷺ) hit it or goaded it (I think) with something he had with him. And after it (it moved so quickly) that it went ahead of all persons and it struggled with me (to move faster than I permitted It) and I had to restrain it. Allah's Messenger (ﷺ) said: Do you sell it at such and such (price)? May Allah grant you pardon. I said: Allah's Apostle, it is yours. He (again) said: Do you sell it at such and such (price)? May Allah grant you pardon. ' I said: Allah's Apostle, it is yours. He said to me: Have you married after the death of your father? I said: Yes. He (again) said: With one previously married or a virgin? I said: With one previously married. He said: Why didn't you marry a virgin who might amuse you and you might amuse her, and she might sport with you and you might sport with her? Abu Nadra said: That was the common phrase which the Muslims spoke:" You do such and such (thing) and Allah may grant you pardon}}
\hadithdefcmd{muslim}{3643}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ الْهَمْدَانِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنَا حَيْوَةُ، أَخْبَرَنِي شُرَحْبِيلُ بْنُ شَرِيكٍ، أَنَّهُ سَمِعَ أَبَا عَبْدِ الرَّحْمَنِ الْحُبُلِيَّ، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الدُّنْيَا مَتَاعٌ وَخَيْرُ مَتَاعِ الدُّنْيَا الْمَرْأَةُ الصَّالِحَةُ‏"‏ ‏.‏\hadithno{3643}\hadithtrans{Abdullah b. Amr reported Allah's Messenger (ﷺ) as saying:The whole world is a provision, and the best object of benefit of the world is the pious woman}}
\hadithdefcmd{muslim}{3644}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي ابْنُ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْمَرْأَةَ كَالضِّلَعِ إِذَا ذَهَبْتَ تُقِيمُهَا كَسَرْتَهَا وَإِنْ تَرَكْتَهَا اسْتَمْتَعْتَ بِهَا وَفِيهَا عِوَجٌ ‏"‏ ‏.‏\hadithno{3644}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Woman is like a rib. When you attempt to straighten it, you would break it. And if you leave her alone you would benefit by her, and crookedness will remain in her}}
\hadithdefcmd{muslim}{3645}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، وَعَبْدُ بْنُ حُمَيْدٍ، كِلاَهُمَا عَنْ يَعْقُوبَ بْنِ إِبْرَاهِيمَ بْنِ سَعْدٍ، عَنِ ابْنِ أَخِي الزُّهْرِيِّ، عَنْ عَمِّهِ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ سَوَاءً ‏.‏\hadithno{3645}\hadithtrans{A hadith like this is reported by another chain of narrators}}
\hadithdefcmd{muslim}{3646}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لاِبْنِ أَبِي عُمَرَ - قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْمَرْأَةَ خُلِقَتْ مِنْ ضِلَعٍ لَنْ تَسْتَقِيمَ لَكَ عَلَى طَرِيقَةٍ فَإِنِ اسْتَمْتَعْتَ بِهَا اسْتَمْتَعْتَ بِهَا وَبِهَا عِوَجٌ وَإِنْ ذَهَبْتَ تُقِيمُهَا كَسَرْتَهَا وَكَسْرُهَا طَلاَقُهَا ‏"‏ ‏.‏\hadithno{3646}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:Woman has been created from a rib and will in no way be straightened for you; so if you wish to benefit by her, benefit by her while crookedness remains in her. And if you attempt to straighten her, you will break her, and breaking her is divorcing her}}
\hadithdefcmd{muslim}{3647}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ مَيْسَرَةَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَإِذَا شَهِدَ أَمْرًا فَلْيَتَكَلَّمْ بِخَيْرٍ أَوْ لِيَسْكُتْ وَاسْتَوْصُوا بِالنِّسَاءِ فَإِنَّ الْمَرْأَةَ خُلِقَتْ مِنْ ضِلَعٍ وَإِنَّ أَعْوَجَ شَىْءٍ فِي الضِّلَعِ أَعْلاَهُ إِنْ ذَهَبْتَ تُقِيمُهُ كَسَرْتَهُ وَإِنْ تَرَكْتَهُ لَمْ يَزَلْ أَعْوَجَ اسْتَوْصُوا بِالنِّسَاءِ خَيْرًا ‏"‏ ‏.‏\hadithno{3647}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Apostle (ﷺ) as saying:He who believes in Allah and the Hereafter, if he witnesses any matter he should talk in good terms about it or keep quiet. Act kindly towards woman, for woman is created from a rib, and the most crooked part of the rib is its top. If you attempt to straighten it, you will break it, and if you leave it, its crookedness will remain there. So act kindly towards women}}
\hadithdefcmd{muslim}{3648}{وَحَدَّثَنِي إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، حَدَّثَنَا عِيسَى، - يَعْنِي ابْنَ يُونُسَ - حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، عَنْ عِمْرَانَ بْنِ أَبِي أَنَسٍ، عَنْ عُمَرَ بْنِ الْحَكَمِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يَفْرَكْ مُؤْمِنٌ مُؤْمِنَةً إِنْ كَرِهَ مِنْهَا خُلُقًا رَضِيَ مِنْهَا آخَرَ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ غَيْرَهُ ‏"‏ ‏.‏\hadithno{3648}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:A believing man should not hate a believing woman; if he dislikes one of her characteristics, he will be pleased with another}}
\hadithdefcmd{muslim}{3649}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، حَدَّثَنَا عِمْرَانُ بْنُ أَبِي أَنَسٍ، عَنْ عُمَرَ بْنِ الْحَكَمِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{3649}\hadithtrans{A hadith like this has been narrated on the authority of Abu Huraira (Allah be pleased with him)}}
\hadithdefcmd{muslim}{3650}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ أَبَا يُونُسَ، مَوْلَى أَبِي هُرَيْرَةَ حَدَّثَهُ عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْلاَ حَوَّاءُ لَمْ تَخُنْ أُنْثَى زَوْجَهَا الدَّهْرَ ‏"‏ ‏.‏\hadithno{3650}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Had it not been for Eve, woman would have never acted unfaithfully towards her husband}}
\hadithdefcmd{muslim}{3651}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْلاَ بَنُو إِسْرَائِيلَ لَمْ يَخْبُثِ الطَّعَامُ وَلَمْ يَخْنَزِ اللَّحْمُ وَلَوْلاَ حَوَّاءُ لَمْ تَخُنْ أُنْثَى زَوْجَهَا الدَّهْرَ ‏"‏ ‏.‏\hadithno{3651}\hadithtrans{Hammam b. Munabbih said:These are some of the ahadith which Abu Huraira (Allah be pleased with him) narrated to us from Allah's Messenger (ﷺ), and one of these (this one): Allah's Messenger (ﷺ) said: Had it not been for Bani Isra'il, food would not have become stale, and meal would not have gone bad; and had it not been for Eve, a woman would never have acted unfaithfully toward her husband}}
